function [ eta, deta ] = compute_buckling( problem, design, solution)

%Extract cross section moments
Mx = abs(solution.f(4,:,1))'; %based on the flapwise load case
h = problem.geometry.h;
matdata = problem.materialdata(1);
E1 = matdata.E1;
E2 = matdata.E2;
nu12 = matdata.nu12;
G12 = matdata.G12;
nu21 = nu12 * E2/E1;

%Moment
M = Mx;

%Build material constitutive matrix Q
Q11 = E1 / (1-nu12*nu21);
Q22 = E2 / (1-nu12*nu21);
Q12 = nu12*E2 / (1-nu12*nu21);
Q66 = G12;
Q_star = Q12 + 2*Q66 + sqrt(Q11*Q22);

%Compute value
eta = 6*M./(pi^2*Q_star.*h) .*design.a./(design.t + design.e).^3;
eta = eta';

%Compute gradient
deta.da = diag( 6*M./(pi^2*Q_star.*h)   .* 1./(design.t + design.e).^3 );
deta.dt = diag( -18*M./(pi^2*Q_star.*h) .* design.a./(design.t + design.e).^4 );
deta.de = diag( -18*M./(pi^2*Q_star.*h) .* design.a./(design.t + design.e).^4 );

end