function [ csprops ] = compute_caps_csprops( problem, design )

%% Parameters
utils.E = problem.materialdata(1).E1;
utils.G = problem.materialdata(1).G12;
utils.rho = problem.materialdata(1).rho;
utils.l = problem.info.delta_z;
utils.h = problem.geometry.h;
utils.c = problem.geometry.c;
utils.N = problem.info.num_sec;

%% Values
%area
csprops.A = 2*design.t.*design.a ;	% beam area [m^2]
Ix = design.a .* design.t.^3/6 + design.a.*design.t/2.*(utils.h-design.t).^2;
Iy = 2 * design.t .* design.a.^3/12;	% second moments of area [m^4]
csprops.K = zeros(size(design.a,1),1);
%stiffness
csprops.EA = utils.E * csprops.A;
csprops.kGA = utils.h * 0.05 * utils.G; %Adding some artifically high shear stiffness to avoid zero shear stiffness
csprops.EIx = utils.E*Ix;
csprops.EIy = utils.E*Iy;	% second moments of area [m^4]
csprops.GK = zeros(size(design.t,1),1);	% torsion constant [m^4]
%mass
csprops.ms = csprops.A .* utils.rho; % mass per unit length
csprops.me = utils.l * csprops.ms; %element mass
csprops.Ix = utils.rho.*Ix;
csprops.Iy = utils.rho.*Iy;

%% Gradients
%area
csprops.dt.A = 2 * design.a;
csprops.da.A = 2 * design.t;
csprops.de.A = zeros(size(design.a,1),1);

dIx = capsdIx( utils, design );
dt.Ix = dIx(:,1); %design.a .* design.t.^2/2 + design.a/2.*(utils.h-design.t).^2-design.a.*design.t.*(utils.h-design.t); %dIx(:,1); 
da.Ix = dIx(:,2); %design.t.^3/6 + design.t/2.*(utils.h-design.t).^2; %dIx(:,2); 
de.Ix = zeros(size(design.a,1),1);

dIy = capsdIy( design );	% second moments of area [m^4]
dt.Iy = dIy(:,1);
da.Iy = dIy(:,2);
de.Iy = zeros(size(design.a,1),1);

csprops.dt.K = zeros(size(design.a,1),1);
csprops.da.K = zeros(size(design.a,1),1);
csprops.de.K = zeros(size(design.a,1),1);

%stiffness
csprops.dt.EA = utils.E * csprops.dt.A;
csprops.da.EA = utils.E * csprops.da.A;
csprops.de.EA = zeros(size(design.e,1),1);

csprops.dt.kGA = zeros(size(design.a,1),1);
csprops.da.kGA = zeros(size(design.t,1),1);
csprops.de.kGA = zeros(size(design.e,1),1);

csprops.dt.EIx = utils.E*dt.Ix;
csprops.da.EIx = utils.E*da.Ix;
csprops.de.EIx = zeros(size(design.e,1),1);

csprops.dt.EIy = utils.E*dt.Iy;
csprops.da.EIy = utils.E*da.Iy;
csprops.de.EIy = zeros(size(design.e,1),1);

csprops.dt.GK = zeros(size(design.t,1),1);	% torsion constant [m^4]
csprops.da.GK = zeros(size(design.a,1),1);	% torsion constant [m^4]
csprops.de.GK = zeros(size(design.e,1),1);	% torsion constant [m^4]

%mass
csprops.dt.ms = csprops.dt.A .* utils.rho; % mass per unit length
csprops.da.ms = csprops.da.A .* utils.rho; % mass per unit length
csprops.de.ms = zeros(size(design.e,1),1); % mass per unit length

csprops.dt.me = utils.l * csprops.dt.ms; %element mass
csprops.da.me = utils.l * csprops.da.ms; %element mass
csprops.de.me = zeros(size(design.a,1),1);%element mass

csprops.dt.Ix = utils.rho.*dt.Ix;
csprops.da.Ix = utils.rho.*da.Ix;
csprops.de.Ix = utils.rho.*de.Ix;

csprops.dt.Iy = utils.rho.*dt.Iy;
csprops.da.Iy = utils.rho.*da.Iy;
csprops.de.Iy = utils.rho.*de.Iy;

    function [ dIx ] = capsdIx( utils, design)
        
        dIx = zeros(size(design.t,1),2);
        
        for s=1:size(design.t,1)
            t = design.t(s);
            a = design.a(s);
            h = utils.h(s);
            
            t1 = t ^ 2;
            t4 = h - t;
            t5 = t4 ^ 2;
            dIx(s,1) = a * t1 / 0.2e1 + a * t5 / 0.2e1 - a * t * t4;
            dIx(s,2) = t1 * t / 0.6e1 + t * t5 / 0.2e1;
            
        end
        
    end

    function [ dIy ] = capsdIy( design )
        
        dIy = zeros(size(design.t,1),2);
        
        for s=1:size(design.t,1)
            t = design.t(s);
            a = design.a(s);
            
            t1 = a ^ 2;
            dIy(s,1) = a * t1 / 0.6e1;
            dIy(s,2) = t1 * t / 0.2e1;
        end
        
        
    end

end

