function [ da, dt, de ] = compute_gradient_KeAndMe( problem, constitutive )
%Gradients of element stiffness and mass matrix
%Note that the function FRANS_B4L which was used to determine the element
%stiffness and mass matrix is now used to compute the gradients of the
%element stiffness and mass matrix by simply giving dKsdx and dMsdx as
%input.

%Aux
mdim = problem.frans.mdim_1d;
N = problem.info.num_sec;

%Gradients
da.Ke = zeros(mdim, mdim, N);
dt.Ke = zeros(mdim, mdim, N);
de.Ke = zeros(mdim, mdim, N);
da.Me = zeros(mdim, mdim, N);
dt.Me = zeros(mdim, mdim, N);
de.Me = zeros(mdim, mdim, N);
for e=1:N
    %dKeda and dMeda
    [ da.Ke(:,:,e), da.Me(:,:,e) ] = FRANS_B4L( e, constitutive.da.Ks(:,:,e),...
        constitutive.da.Ms(:,:,e), problem.frans );
    %dKedt and dMedt
    [ dt.Ke(:,:,e), dt.Me(:,:,e) ] = FRANS_B4L( e, constitutive.dt.Ks(:,:,e),...
        constitutive.dt.Ms(:,:,e), problem.frans );
    %dKede and dMede
    [ de.Ke(:,:,e), de.Me(:,:,e) ] = FRANS_B4L( e, constitutive.de.Ks(:,:,e), ...
        constitutive.de.Ms(:,:,e), problem.frans );
end

end