function [ da, dt, de ] = compute_gradient_KsAndMs( problem, csprops )
%Compute gradients of cross section stiffness and mass matrix

N = problem.info.num_sec;
da.Ks = zeros(6,6,N);
da.Ms = zeros(6,6,N);
dt.Ks = zeros(6,6,N);
dt.Ms = zeros(6,6,N);
de.Ks = zeros(6,6,N);
de.Ms = zeros(6,6,N);

%% Gradients 
%Using compute_Ks to assemble dKsdx by simply providing the gradients of
%the cross section stiffness properties as input

% Gradient w.r.t. a
csprops_aux = csprops.total.da;
for s = 1:N
    [ da.Ks(:,:,s) ] = compute_Ks( csprops_aux.kGA(s), csprops_aux.EA(s), ...
        csprops_aux.EIx(s), csprops_aux.EIy(s), csprops_aux.GK(s) );
    [ da.Ms(:,:,s) ] = compute_Ms( csprops_aux.ms(s), csprops_aux.Ix(s), ...
        csprops_aux.Iy(s) );
end

% Gradients w.r.t. t
csprops_aux = csprops.total.dt;
for s = 1:N
    [ dt.Ks(:,:,s) ] = compute_Ks( csprops_aux.kGA(s), csprops_aux.EA(s), ...
        csprops_aux.EIx(s), csprops_aux.EIy(s), csprops_aux.GK(s) );
    [ dt.Ms(:,:,s) ] = compute_Ms( csprops_aux.ms(s), csprops_aux.Ix(s), ...
        csprops_aux.Iy(s) );
end

% Gradients w.r.t. e
csprops_aux = csprops.total.de;
for s = 1:N
    [ de.Ks(:,:,s) ] = compute_Ks( csprops_aux.kGA(s), csprops_aux.EA(s), ...
        csprops_aux.EIx(s), csprops_aux.EIy(s), csprops_aux.GK(s) );
    [ de.Ms(:,:,s) ] = compute_Ms( csprops_aux.ms(s), csprops_aux.Ix(s), ...
        csprops_aux.Iy(s) );
end

end

