function [ c, dc, ceq, dceq ] = compute_store_constraints( problem, u_tip, dudx_tip, strain, dstrain, eta, deta, w, dw )

%Aux
scaling = problem.scaling;
N = problem.info.num_sec;

% Initialize output
c = zeros(1, 1+3*N);  % 1 tip disp. constraint + N cap strain constraints + N ellipse strain constraints + N buckling constraints + 1 frequency constraint
dc = zeros(3*N, 1+3*N);  % gradients of the constraints
ceq = []; % must be specified!
dceq = []; % must be specified!

%% DISPLACEMENT
max_tip_disp = problem.constraints.max_tip_disp;
%Store value
c(1) = (u_tip-max_tip_disp) / scaling.char_disp;  % inequality constraint  c(x) <= 0
%Store gradient
dc(:,1) = [ dudx_tip.da * scaling.char_a / scaling.char_disp;
    dudx_tip.dt * scaling.char_t / scaling.char_disp;
    dudx_tip.de * scaling.char_e / scaling.char_disp;];

%% STRAINS
%Store value
max_strain = problem.constraints.max_strain;
c(1, 2:N+1) = (strain(:,1) - max_strain(1)) ./ scaling.char_strain;
c(1, N+2:2*N+1) = (strain(:,2) - max_strain(2)) ./ scaling.char_strain;

%Store gradient
dc(:,2:N+1) = [ dstrain(1).da * scaling.char_a / scaling.char_strain;
    dstrain(1).dt * scaling.char_t / scaling.char_strain;
    dstrain(1).de * scaling.char_e / scaling.char_strain];
dc(:,N+2:2*N+1) = [ dstrain(2).da * scaling.char_a / scaling.char_strain;
    dstrain(2).dt * scaling.char_t / scaling.char_strain;
    dstrain(2).de * scaling.char_e / scaling.char_strain];

%% BUCKLING
eta_max = problem.constraints.max_buckling_factor;
%Store value
c(1, 2*N+2:3*N+1) = eta-eta_max;  % inequality constraints c(x) <= 0
%Store gradient
dc(:,2*N+2:3*N+1) = [ deta.da * scaling.char_a;
    deta.dt * scaling.char_t;
    deta.de * scaling.char_e];


%% FREQUENCIES
nfreq = length(problem.constraints.max_freq);

%Upper bound
for iw = 1:nfreq %Loop frequencies
    %Store value
    c(1,end+1)=(w(iw)-(problem.constraints.max_freq(iw)*2*pi)^2) / scaling.char_freq;
    %Store gradient
    dc(:,end+1) = [ dw.da(:,iw) * scaling.char_a/scaling.char_freq;
        dw.dt(:,iw) * scaling.char_t/scaling.char_freq;
        dw.de(:,iw) * scaling.char_e/scaling.char_freq ];
end

%Lower bound
for iw = 1:nfreq %Loop frequencies
    %Store value
    c(1,end+1) = -(w(iw)-(problem.constraints.min_freq(iw)*2*pi)^2)/ scaling.char_freq;
    %Store gradient
    dc(:,end+1) = -[ dw.da(:,iw) * scaling.char_a/scaling.char_freq;
        dw.dt(:,iw) * scaling.char_t/scaling.char_freq;
        dw.de(:,iw) * scaling.char_e/scaling.char_freq ];
end

end
