function [ strain, dstrain ] = compute_strains( problem, csprops, solution )

%Aux
EIx = csprops.total.EIx; %Bending stiffness around x axis
EIy = csprops.total.EIy; %Bending stiffness around y axis

EIxda = csprops.total.da.EIx; %Bending stiffness around x axis
EIxdt = csprops.total.dt.EIx; %Bending stiffness around x axis
EIxde = csprops.total.de.EIx; %Bending stiffness around x axis

EIyda = csprops.total.da.EIy; %Bending stiffness around y axis
EIydt = csprops.total.dt.EIy; %Bending stiffness around y axis
EIyde = csprops.total.de.EIy; %Bending stiffness around y axis

caps_h = problem.geometry.h;
ellipse_c = problem.geometry.c;

%Value
%Extract cross section moments
Mx = abs(solution.f(4,:,1))'; %based on edgewise load case
My = abs(solution.f(5,:,2))'; %based on flapwise load case

% Compute section curvature
kappax = Mx./(EIx);
kappay = My./(EIy);

% Compute bending strains
strain(:,1) = kappax.*caps_h/2; %caps
strain(:,2) = kappay.*ellipse_c/2; %ellipse

%Gradient
% Construct the gradients of the curvature
%Note tha E is also squared and so we multiply by EIxda
dkappax.da = diag( -Mx ./ (EIx.^2) .* ( EIxda ) );
dkappax.dt = diag( -Mx ./ (EIx.^2) .* ( EIxdt ) );
dkappax.de = diag( -Mx ./ (EIx.^2) .* ( EIxde ) );

dkappay.da = diag( -My ./ (EIy.^2) .* ( EIyda ) );
dkappay.dt = diag( -My ./ (EIy.^2) .* ( EIydt ) );
dkappay.de = diag( -My ./ (EIy.^2) .* ( EIyde ) );

% Compute the gradients of the bending strain
dstrain(1).da = dkappax.da .* diag(caps_h/2); %caps
dstrain(1).dt = dkappax.dt .* diag(caps_h/2);
dstrain(1).de = dkappax.de .* diag(caps_h/2);

dstrain(2).da = dkappay.da .* diag(ellipse_c/2); %ellipse
dstrain(2).dt = dkappay.dt .* diag(ellipse_c/2);
dstrain(2).de = dkappay.de .* diag(ellipse_c/2);

end