function [ u_tip, dudx_tip, du ] = compute_tip_displacement( problem, beam, solution )

%% Compute tip displacement constraint
N = problem.info.num_sec;
edof = problem.frans.edof_1d; %element degrees of freedom, each column is an element
disp = solution.u(:,1); %Using displacements from flapwise load case

%Value
%dof for tip displacement uy
nn_tip = problem.frans.nn_1d;
dof_tip = (nn_tip-1)*6+2;

%Extract tip displacement
u_tip = disp(dof_tip); 

%Gradient
%First we determine dKdx*u by multiplying dKdx with u but elementwise, i.e., dKedx*ue because each
%design variable affects only one element. The resulting column vector is
%mapped onto dKdxu which has the size of K.
dKdxu = zeros(size(beam.K,1),N*3);
for e = 1:N
    ue = disp(edof(:,e));
    dKdxu(edof(:,e),e) = beam.da.Ke(:,:,e) * ue;
    dKdxu(edof(:,e),e+N) = beam.dt.Ke(:,:,e) * ue;
    dKdxu(edof(:,e),e+2*N) = beam.de.Ke(:,:,e) * ue;
end

%Determine gradient of displacements
dudx = - beam.K \ dKdxu;

%Storing gradient values for output
du.da = dudx(:,1:N);
du.dt = dudx(:,N+1:2*N);
du.de = dudx(:,2*N+1:end);

%Extract tip displacement gradients
dudx_tip.da = dudx(dof_tip,1:N)';
dudx_tip.dt = dudx(dof_tip,N+1:2*N)';
dudx_tip.de = dudx(dof_tip,2*N+1:end)';

end