% ===================================================================
% Course 46415
% Structural Analysis and Design Optimization of Wind Turbine Blades 
% Mini-Project 2: Optimum Blade
% Written by 
% Jos P. Blasques (jpbl@dtu.dk) and Robert D. Bitsche (robi@dtu.dk)
% DTU Wind Energy
% ===================================================================

%% Clean up
clearvars; close all; clc; clear global;

%% Add paths
addpath(genpath('opt'),genpath('data'),genpath('plot'),genpath('analysis'),genpath('validation'));

%% Define problem structure as global variable
global problem;

%% Define input parameters
problem = define_input;

%% Compute initial solution
design_nondimensional = scale2dimensionless(problem.initial_design, problem.scaling); % scale to nondimensional values
x = [design_nondimensional.a; design_nondimensional.t; design_nondimensional.e]; % build design variable vector
compute_constraints( x ); % compute the initial constraint values
compute_objective( x );   % compute the initial objective function value
problem.info.initial_solution = problem.info.saved_solution; % save the initial solution

%% Print initial solution to screen
print_solution( problem.info.saved_solution, 'Initial Solution' );

%% Check gradients finite differences
%fd_checker(@compute_constraints, x, 1e-6, 62:65 )
%return;

%% Initialize plots
problem.options.plotting.axes = initialize_plots( problem );

%% Plot the initial solution
plot_solution( problem, problem.initial_design, problem.info.initial_solution, '--k.', 0 );
plot_solution( problem, problem.initial_design, problem.info.initial_solution, '-r.', 0 );

%% Wait for keypress to start optimization
fprintf('Paused after computing initial solution.\n');
fprintf('Press any key to start optimization.\n');
pause;

%% Run Optimizer
[ design_opt, m_opt, output, exitflag, lambda ] = run_fmincon( problem );

%% Compute final solution
design_nondimensional = scale2dimensionless(design_opt, problem.scaling); 
x = [design_nondimensional.a; design_nondimensional.t; design_nondimensional.e];
compute_constraints( x );
compute_objective( x );
problem.info.final_solution = problem.info.saved_solution;
problem.info.final_solution.iteration = output.iterations;
problem.info.final_solution.firstorderopt = output.firstorderopt;

%% Print and plot final solution
print_solution( problem.info.final_solution, 'Final Solution' );
plot_solution( problem, design_opt, problem.info.final_solution, '-r.', 1);

%% Check exitflag
if exitflag < 1
    fprintf('WARNING: exitflag was smaller than 1.\n  exitflag = %g \n', exitflag)
end
