function [ obj, dobj, m, dm ] = compute_objective( x )
%Compute the objective function and the gradients of the objective
%function.

global problem

%% Design variables
scaling = problem.scaling;
N = problem.info.num_sec;
design_dimless = [];  % convert the dimensionless values in x into a structure
design_dimless.a = x(1:N);
design_dimless.t = x(N+1:2*N);
design_dimless.e = x(2*N+1:end);
design = scale2physical(design_dimless, problem.scaling); % scale to physical values

%% Analysis
[ csprops ] = compute_csprops( problem, design ); % Cross section properties
m = sum(csprops.total.me);	% m: total beam mass [kg]

%Calculate gradients
dm.da = csprops.total.da.me;
dm.dt = csprops.total.dt.me;
dm.de = csprops.total.de.me;

%% Scaling and storing
obj = m / scaling.char_m;  % scale result to dimensionless values

dobj = [dm.da' * scaling.char_a/scaling.char_m ...
    dm.dt' * scaling.char_t/scaling.char_m ...
    dm.de' * scaling.char_e/scaling.char_m];

%% Plotting purposes
problem.info.saved_solution.m = m;
problem.info.saved_solution.mass_per_length = csprops.total.ms;

end
