function plot_freq(problem, indxf, f, lb, ub, iteration )
%Plot current first eigenfrequency using a animatedline plot
%   Written by 
%   Jos P. Blasques (jpbl@dtu.dk) and Robert D. Bitsche (robi@dtu.dk)
%   DTU Wind Energy

axes_handle = problem.options.plotting.axes.freq(indxf);
fig = axes_handle.Parent;
set(0, 'currentfigure', fig);
set(fig,'CurrentAxes',axes_handle)

%% Reasonable default behavior if iteration is not specified as input argument
if nargin < 6
    graphics = flip(axes_handle.Children);
    if isempty(graphics)
        iteration = 0;
    else
        h = graphics(1);
        [xvals,~] = getpoints(h);
        iteration=xvals(end);
    end
end

%% Compute relative frequency change
rel_change = (f(indxf)/problem.info.initial_solution.freq(indxf)-1)*100;

%% Plot or update plot

if isempty(axes_handle.Children)  % Nothing in the figure yet.
    animatedline(iteration,lb(indxf),'Marker','.','Color','c');
    animatedline(iteration,ub(indxf),'Marker','.','Color','c');
    animatedline(iteration,f(indxf),'Marker','.','Color','b');
    ylim([0 1.1*max(ub)]);
    grid on;
    text(0.95,0.4,sprintf(' %.2f%%',rel_change),'Units','Normalized','HorizontalAlignment','right');
else
    graphics = flip(axes_handle.Children);
    h_lb=graphics(1);
    h_ub=graphics(2);
    h=graphics(3); % annimated line    
    t=graphics(4); % text
    t.String=(sprintf('%.2f%%',rel_change));
    addpoints(h,iteration,f(indxf));
    addpoints(h_lb,iteration,lb(indxf));
    addpoints(h_ub,iteration,ub(indxf));
end

drawnow;
end

