function plot_mass(problem, m, iteration )
%Plot current mass using a animatedline plot
%   Written by 
%   Jos P. Blasques (jpbl@dtu.dk) and Robert D. Bitsche (robi@dtu.dk)
%   DTU Wind Energy

axes_handle = problem.options.plotting.axes.mass;
fig = axes_handle.Parent;
set(0, 'currentfigure', fig);
set(fig,'CurrentAxes',axes_handle)

%% Reasonable default behavior if iteration is not specified as input argument
if nargin < 3
    graphics = flip(axes_handle.Children);
    if isempty(graphics)
        iteration = 0;
    else
        h = graphics(1);
        [xvals,~] = getpoints(h);
        iteration=xvals(end);  
    end
end

%% Compute relative mass change
rel_change = (m/problem.info.initial_solution.m-1)*100;

%% Plot or update plot
if isempty(axes_handle.Children)  % Nothing in the figure yet.
    animatedline(iteration,m,'Marker','.','Color','b');
    ylim([0 1.1*m]);
    grid on;
    text(0.95,0.4,sprintf('%.2f%%',rel_change),'Units','Normalized','HorizontalAlignment','right');
else
    graphics = flip(axes_handle.Children);
    h=graphics(1); % annimated line
    t=graphics(2); % text
    addpoints(h,iteration,m);
    t.String=(sprintf('%.2f%%',rel_change));
end
drawnow;
end


