function plot_solution( problem, design, solution, LineSpec, update )
% Plot a problem solution
%   update = 0: Plot new lines
%   update = 1: Update the most recently plotted lines
%
%   Written by
%   Jos P. Blasques (jpbl@dtu.dk) and Robert D. Bitsche (robi@dtu.dk)
%   DTU Wind Energy

%% Plot design variables
axes_handle = problem.options.plotting.axes.cap_width;
update_plot( axes_handle, problem.info.z_eval, design.a, LineSpec, update );

axes_handle = problem.options.plotting.axes.cap_thick;
update_plot( axes_handle, problem.info.z_eval, design.t, LineSpec, update );

axes_handle = problem.options.plotting.axes.ellipse_thick;
update_plot( axes_handle, problem.info.z_eval, design.e, LineSpec, update );

%% Plot mass per length
if isfield(solution,'mass_per_length')
    axes_handle = problem.options.plotting.axes.mpl;
    update_plot( axes_handle, problem.info.z_eval, solution.mass_per_length, LineSpec, update );
end

%% Plot deflection curve
axes_handle = problem.options.plotting.axes.defo;
uy = solution.deflection(2:18:end);
update_plot( axes_handle, problem.info.z_nodes, uy, LineSpec, update );

%% Plot buckling factors
axes_handle = problem.options.plotting.axes.buckling;
update_plot( axes_handle, problem.info.z_eval, solution.eta, LineSpec, update );

%% Plot strains caps
%FIXME: can't plot strains in the ellipse
axes_handle = problem.options.plotting.axes.strain_caps;
update_plot( axes_handle, problem.info.z_eval, solution.strain(:,1), LineSpec, update );

%% Plot strains caps
%FIXME: can't plot strains in the ellipse
axes_handle = problem.options.plotting.axes.strain_ellipse;
update_plot( axes_handle, problem.info.z_eval, solution.strain(:,2), LineSpec, update );

%% Plot mass
if isfield(solution,'iteration')
    plot_mass(problem, solution.m, solution.iteration)
else
    plot_mass(problem, solution.m)
end

%% Plot frequencies
nf = length(problem.constraints.max_freq);
for indxf = 1 : nf
    lb = problem.constraints.min_freq;
    ub = problem.constraints.max_freq;
    if isfield(solution,'iteration')
        plot_freq(problem, indxf, solution.freq, lb, ub, solution.iteration)
    else
        plot_freq(problem, indxf, solution.freq, lb, ub)
    end
end
%% Plot first-order optimality
if isfield(solution,'firstorderopt')
   update_foo_plot( problem, solution.iteration, solution.firstorderopt, '-b.' )
end    

drawnow;

end

